@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 
 # Copyright 2015 Sam Yaple
 #
@@ -180,7 +180,7 @@ EXAMPLES = '''
         action: remove_container
     - name: Pull image without starting container
       kolla_docker:
-        action: pull_container
+        action: pull_image
         image: private-registry.example.com:5000/ubuntu
     - name: Create named volume
         action: create_volume
@@ -198,10 +198,7 @@ import docker
 
 
 def get_docker_client():
-    try:
-        return docker.Client
-    except AttributeError:
-        return docker.APIClient
+    return docker.APIClient
 
 
 class DockerWorker(object):
@@ -436,6 +433,12 @@ class DockerWorker(object):
         else:
             return full_image, 'latest'
 
+    def get_image_id(self):
+        full_image = self.params.get('image')
+
+        image = self.dc.images(name=full_image, quiet=True)
+        return image[0] if len(image) == 1 else None
+
     def pull_image(self):
         if self.params.get('auth_username'):
             self.dc.login(
@@ -446,6 +449,7 @@ class DockerWorker(object):
             )
 
         image, tag = self.parse_image()
+        old_image_id = self.get_image_id()
 
         statuses = [
             json.loads(line.strip().decode('utf-8')) for line in self.dc.pull(
@@ -468,23 +472,8 @@ class DockerWorker(object):
                         failed=True
                     )
 
-            if status and status.get('status'):
-                # NOTE(SamYaple): This allows us to use v1 and v2 docker
-                # registries.  Eventually docker will stop supporting v1
-                # registries and when that happens we can remove this.
-                if 'legacy registry' in status['status']:
-                    continue
-                elif 'Downloaded newer image for' in status['status']:
-                    self.changed = True
-                    return
-                elif 'Image is up to date for' in status['status']:
-                    return
-                else:
-                    self.module.fail_json(
-                        msg="Unknown status message: {}".format(
-                            status['status']),
-                        failed=True
-                    )
+        new_image_id = self.get_image_id()
+        self.changed = old_image_id != new_image_id
 
     def remove_container(self):
         if self.check_container():
@@ -511,6 +500,9 @@ class DockerWorker(object):
         vol_dict = dict()
 
         for vol in volumes:
+            if len(vol) == 0:
+                continue
+
             if ':' not in vol:
                 vol_list.append(vol)
                 continue
@@ -600,6 +592,7 @@ class DockerWorker(object):
         # If config_strategy is COPY_ONCE or container's parameters are
         # changed, try to start a new one.
         if config_strategy == 'COPY_ONCE' or self.check_container_differs():
+            self.stop_container()
             self.remove_container()
             self.start_container()
         elif config_strategy == 'COPY_ALWAYS':
@@ -611,6 +604,7 @@ class DockerWorker(object):
 
         container = self.check_container()
         if container and self.check_container_differs():
+            self.stop_container()
             self.remove_container()
             container = self.check_container()
 
@@ -636,6 +630,7 @@ class DockerWorker(object):
                     msg="Container exited with non-zero return code %s" % rc
                 )
             if self.params.get('remove_on_exit'):
+                self.stop_container()
                 self.remove_container()
 
     def get_container_env(self):
@@ -664,23 +659,29 @@ class DockerWorker(object):
 
     def stop_container(self):
         name = self.params.get('name')
+        graceful_timeout = self.params.get('graceful_timeout')
+        if not graceful_timeout:
+            graceful_timeout = 10
         container = self.check_container()
         if not container:
             self.module.fail_json(
                 msg="No such container: {} to stop".format(name))
         elif not container['Status'].startswith('Exited '):
             self.changed = True
-            self.dc.stop(name)
+            self.dc.stop(name, timeout=graceful_timeout)
 
     def restart_container(self):
         name = self.params.get('name')
+        graceful_timeout = self.params.get('graceful_timeout')
+        if not graceful_timeout:
+            graceful_timeout = 10
         info = self.get_container_info()
         if not info:
             self.module.fail_json(
                 msg="No such container: {}".format(name))
         else:
             self.changed = True
-            self.dc.stop(name)
+            self.dc.stop(name, timeout=graceful_timeout)
             self.dc.start(name)
 
     def create_volume(self):
@@ -732,6 +733,7 @@ def generate_module():
         security_opt=dict(required=False, type='list', default=list()),
         pid_mode=dict(required=False, type='str', choices=['host', '']),
         privileged=dict(required=False, type='bool', default=False),
+        graceful_timeout=dict(required=False, type='int', default=10),
         remove_on_exit=dict(required=False, type='bool', default=True),
         restart_policy=dict(required=False, type='str', choices=[
                             'no',
